#
# spec file for package python-xdoctest
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-xdoctest
Version:        1.1.1
Release:        1.4
Summary:        Enhanced Python builtin doctest module
License:        Apache-2.0
URL:            https://github.com/Erotemic/xdoctest
Source:         https://github.com/Erotemic/xdoctest/archive/refs/tags/v%{version}.tar.gz#/xdoctest-%{version}.tar.gz
# https://github.com/Erotemic/xdoctest/pull/142
Patch0:         python-xdoctest-no-six.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pygments}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun):update-alternatives
Recommends:     python-pygments
BuildArch:      noarch
%python_subpackages

%description
A rewrite of the builtin doctest module with a pytest plugin.

%prep
%autosetup -p1 -n xdoctest-%{version}

%build
sed -i '1{/^#!/d}' src/xdoctest/__main__.py
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/xdoctest
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative xdoctest

%postun
%python_uninstall_alternative xdoctest

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/xdoctest
%{python_sitelib}/xdoctest*

%changelog
* Tue Jun  6 2023 pgajdos@suse.com
- version update to 1.1.1
  [#]# Version 1.1.1
  [#]## Changed
  * Binary tests are now only run on "full" installs to reduce minimal dependencies.
  * Support for Python 3.11
  * Minor typing fixes
  [#]# Version 1.1.0 - Released 2022-09-05
  [#]## Fixed
  * Can now handle basic versions of the new `__editable__` package finder mechanism.
  * Parsing bug where directives were incorrectly flagged as inline if they were
    directly followed by a function with a decorator.
  [#]## Removed
  * Dropped 2.7 and 3.5 support. Now supporting 3.6+ Use xdoctest<=1.0.2 for 2.7
    or 3.5 support.
  [#]## Changed
  * Improved the "dump" functionality of converting doctests to unit tests.
  [#]# Version 1.0.2 - Released 2022-08-19
  [#]## Added
  * Environs as options:
    `XDOCTEST_VERBOSE`, `XDOCTEST_OPTIONS`, `XDOCTEST_GLOBAL_EXEC`, `XDOCTEST_REPORT`,
    `XDOCTEST_STYLE`, and `XDOCTEST_ANALYSIS` environment variables can now be used
    to specify configuration defaults.
  [#]## Changed
  * Added experimental hidden feature `--insert-skip-directive-above-failures`
    that can be used to modify your code such that failing doctests are marked as
    skip.
  * Disabled traceback suppression on module import errors (this is is
    configurable via the `supress_import_errors` option).
  * Xdoctest will no longer try to pre-import the module if none of its doctests
    have any enabled lines. This also means global-exec statements will NOT run
    for those tests, which means you can no longer use global-exec to
    force enabling tests.
  [#]# Version 1.0.1 - Released 2022-07-10
  [#]## Added
  * Add type stubs
  * Basic support for pyproject.toml under `tool.xdoctest`. Currently only
    supports options in the native runner.
  [#]## Fixed
  * Corner case bug in error reporting
  * Doctests that never run any code are now correctly marked as skipped
  * Issue where the "dumps" command was undocumented and has an error.
  [#]## Changed
  * Moved some globals into a new module called `global_state` and allowed
    environs to enable debug print statements.
  * Added `util_deprecation` module to robustly mark features as deprecated.
  * Modified the google style return type parser to return a type if the
    only content is some parsable python code.
  * Modified docscrape google to allow for parsing of `*args` and `**kwargs` in
    args blocks. This has also moved to the standalone package `googledoc`
  * Overhaul of repo structure in an effort to modernize and to agree with
    templates defined by xcookie
  * Module code now lives in the "src" directory to remove install vs develop
    ambiguity.
  [#]# Version 1.0.0 - Released 2022-03-25
  [#]## Added
  * Support for Python 3.10
  [#]## Fixed
  * Warning in pytest8
  * Spelling errors in documentation
  * added patches
  https://github.com/Erotemic/xdoctest/pull/142
  + python-xdoctest-no-six.patch
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- update to 0.15.10:
  * The xdoctest "analysis" option now defaults to "auto" everywhere.
  * Disabled workaround 16806 in Python 3.8+
  * Removed the distracting and very long internal traceback
  * Pytest now defaults to --xdoctest-verbose=2 by default
  * Directive syntax errors are now handled as doctest runtime errors and
    return better debugging information
- drop 97.patch, upstream
* Fri Feb 19 2021 Dirk Müller <dmueller@suse.com>
- update to 0.15.4:
  * pip install xdoctest can now specify [colors] or [jupyter]
  * Enhanced REQUIRES directive behavior
  * Xdoctest can now be run inside of Jupyter notebooks / IPython sessions
  * Xdoctest can now be run on Jupyter notebooks
  * Renamed Config to DoctestConfig
  * Renamed static_analysis.parse_calldefs to
    static_analysis.parse_static_calldefs.
  * Changed argument name from modpath_or_name to module_identifier in several
    functions.
  * The REQUIRES directive can now inspect existence or values of environment
    variables.
  * Bugfixes
  * add 97.patch
* Tue Aug 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the download url
* Sun Aug 16 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.13.0
* Fri Sep  6 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.10.0
